<p align="center">
  
</p>

#


## Description

WP Audit is an open source multi-cloud security-auditing tool, which enables security posture assessment of cloud environments. Using the APIs exposed by cloud providers, WP Audit gathers configuration data for manual inspection and highlights risk areas. Rather than going through dozens of pages on the web consoles, WP Audit presents a clear view of the attack surface automatically.

WP Audit was designed by security consultants/auditors. It is meant to provide a point-in-time security-oriented view of the cloud account it was run in. Once the data has been gathered, all usage may be performed offline.


### Cloud Provider Support

The following cloud providers are currently supported:

- Amazon Web Services
- Microsoft Azure
- Google Cloud Platform
- Alibaba Cloud (alpha)
- Oracle Cloud Infrastructure (alpha)

## Installation

Refer to the [wiki](https://github.com/wperic/wpaudit/wiki/Setup).

## Usage


